##  General Permissions
The General Permissions section includes permissions that apply to the entire fact sheet type. These permissions are not based on the CRUD format. You can enable or disable them by selecting or deselecting the corresponding checkboxes.
The following table lists general fact sheet permissions.
Permission | Description | Additional Information
---|---|---
Create Fact Sheets | Allows users to create fact sheets of this type. |  [Creating Fact Sheets](https://help.sap.com/docs/leanix/ea/creating-fact-sheets?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to create fact sheets in the inventory. This guide also covers fact sheet naming conventions and cloning fact sheets.")
Read Fact Sheets | Allows users to view fact sheets of this type. This permission takes precedence over individual field permissions. |  [Inventory](https://help.sap.com/docs/leanix/ea/inventory?locale=en-US&state=PRODUCTION&version=CLOUD "The inventory is your centralized repository for managing and documenting enterprise architecture objects. You create, edit, and organize fact sheets to maintain an accurate depiction of your IT landscape. It is the go-to place for anyone seeking information from the fact sheets.")
Archive Fact Sheets | Allows users to archive fact sheets of this type. |  [Archiving and Recovering Fact Sheets](https://help.sap.com/docs/leanix/ea/archiving-deleting-and-recovering-fact-sheets?locale=en-US&state=PRODUCTION&version=CLOUD "Learn to archive fact sheets individually or in bulk and effortlessly view or recover archived fact sheets in SAP LeanIX.")
Inline Table Editing | Allows users to edit fact sheet data in the inventory table view. |  [Inline Editing](https://help.sap.com/docs/leanix/ea/adding-and-editing-data-in-fact-sheets?locale=en-US&state=PRODUCTION&version=CLOUD "Users with the appropriate permissions can add and edit data in fact sheets, while administrators can customize and manage these permissions. By switching to table view in the inventory, you can perform inline editing across multiple fact sheets, and using the import option, you can update multiple fact sheets in bulk.")
Import Fact Sheets | Allows users to import fact sheets and related data using the following features: - Excel import (for all fact sheet types) - Reference catalog (for business capabilities) |  [Importing Fact Sheet Data Through Excel File](https://help.sap.com/docs/leanix/ea/importing-fact-sheet-data-through-excel-file?locale=en-US&state=PRODUCTION&version=CLOUD "SAP LeanIX’s import feature enables efficient bulk updates, including adding, updating, and archiving fact sheets. This guide provides formatting rules, error handling, and step-by-step guidance for importing data through an Excel file.") [Business Capabilities in the Reference Catalog](https://help.sap.com/docs/leanix/ea/business-capabilities-in-reference-catalog?locale=en-US&state=PRODUCTION&version=CLOUD "Import business capabilities from best-practice, industry-specific business capabilities and customize them to suit your organization’s needs.")
Export Fact Sheets | Allows users to export fact sheets and related data using the Excel export feature. |  [Exporting Fact Sheet Data as Excel File](https://help.sap.com/docs/leanix/ea/exporting-fact-sheet-data-as-excel-file?locale=en-US&state=PRODUCTION&version=CLOUD "SAP LeanIX’s export feature allows you to export fact sheet data as an Excel file for bulk updates, easy data manipulation, and offline analysis. The exported file also serves as a template for importing data back into SAP LeanIX.")


